/*
 * (c) Bernd Müller & Harald Wehr, www.jpainfo.de
 */
package de.jpainfo.test;

import java.text.DateFormat;
import java.text.SimpleDateFormat;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

import de.jpainfo.model.Anrede;
import de.jpainfo.model.ec2.Kunde;
import de.jpainfo.model.ec2.Telefon;
import de.jpainfo.model.ec2.Telefonart;


public class TestElementCollectionMap {
	
	private static final DateFormat format = new SimpleDateFormat("dd.MM.yyyy");

	public static void main(String[] args) throws Exception {
		
		Provider.select("eclipselink");
		
		EntityManagerFactory emf = Persistence.createEntityManagerFactory("bank");
		EntityManager em = emf.createEntityManager();

		em.getTransaction().begin();
		Kunde kunde1 = new Kunde("Max", "Mustermann", format.parse("29.7.1962"), Anrede.HERR);
		kunde1.getTelefone().put(Telefonart.FIRMA, new Telefon(Telefonart.FIRMA, "05331 firma"));
		kunde1.getTelefone().put(Telefonart.PRIVAT, new Telefon(Telefonart.PRIVAT, "05331 privat"));
		kunde1.getTelefone().put(Telefonart.MOBIL, new Telefon(Telefonart.MOBIL, "0172 mobil"));
		em.persist(kunde1);
		Integer id = kunde1.getId();
		kunde1 = em.find(Kunde.class, id);
		System.out.println("Kunde " + kunde1 + " hat " + kunde1.getTelefone().size() + " Telefone");
		
		Kunde kunde2 = new Kunde("Emil", "Schulz", format.parse("1.1.1970"), Anrede.HERR);
		kunde2.getTelefone().put(Telefonart.PRIVAT, new Telefon(Telefonart.PRIVAT, "05331 123")); // kein MOBIL
		em.persist(kunde2);
		Kunde kunde3 = new Kunde("Lisa", "Meier", format.parse("14.4.1967"), Anrede.FRAU);
		kunde3.getTelefone().put(Telefonart.MOBIL, new Telefon(Telefonart.MOBIL, "05331 123"));
		em.persist(kunde3);
		em.getTransaction().commit();
		
		
		// geht nur mit OpenJPA. EclipseLink und Hibernate liefern Fehler
//		em.getTransaction().begin();
//		TypedQuery<Kunde> query = em.createQuery("select k from Kunde k JOIN k.telefone t where VALUE(t).art = Telefonart.MOBIL", Kunde.class);
//		List<Kunde> kunden = query.getResultList();
//		for (Kunde kunde : kunden) {
//			System.out.println("Kunde mit Mobiltelefon: " + kunde);
//		}
//		em.getTransaction().commit();
		
		

		em.clear();
		emf.close();
	}
}
